@@ -1,3 +1,5 @@
+import hashlib
+
 from django.core.cache import cache
 
 from ratelimit.backends import BaseBackend
@@ -15,7 +17,10 @@ class CacheBackend(BaseBackend):
             if not isinstance(field, (list, tuple)):
                 field = [field]
             for f in field:
-                val = getattr(request, request.method).get(f)
+                val = getattr(request, request.method).get(f, '').encode('utf-8')
+                # Convert value to hexdigest as cache backend doesn't allow
+                # certain characters.
+                val = hashlib.sha1(val).hexdigest()
                 keys.append(u'field:%s:%s' % (f, val))
         return [CACHE_PREFIX + k for k in keys]
 
